/*
   FALCON - The Falcon Programming Language.
   FILE: verion.h

   Falcon RTL module version informations
   -------------------------------------------------------------------
   Author: Giancarlo Niccolai
   Begin: 2007-07-25


   -------------------------------------------------------------------
   (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)

   See LICENSE file for licensing details.
*/

#ifndef RTL_VERSION_H
#define RTL_VERSION_H

#define RTL_VERSION_MAJOR        0
#define RTL_VERSION_MINOR        8 
#define RTL_VERSION_REVISION     0

#endif

/* end of version.h */
